@@ -2,21 +2,21 @@ import httpx
 from . import console
 import rich.progress
 from pathlib import Path
+import boto3
 
 def get_signed_url(object_name: str) -> str:
-    r = httpx.get(
-        'https://sign.tiles.demo.internal.spacerake.net/api/v0/presign',
-        params={
-            'key': object_name
-        }
+    s3_client = boto3.client('s3')
+    response = s3_client.generate_presigned_url(
+        'get_object',
+        Params={
+            'Bucket': 'spacerake',
+            'Key': object_name
+        },
+        ExpiresIn=(2 * 60 * 60) # two hours
     )
-    r = r.json()
 
-    if not 'ok' in r or not r['ok']:
-        console.print(r)
-        raise RuntimeError(f'couldn\'t sign url for key {object_name}')
+    return response
 
-    return r['signed_url']
 
 def download_dataset(dataset_name: str, output: Path):
 
