@@ -360,10 +360,10 @@ class Sample:
         row = cursor.fetchone()
 
         # prep to load in numpy file
-        io = BytesIO()
-        io.write(row['img_raw'])
-        io.seek(0) # rewind to start of file
-        raw_mask = np.load(io)
+        # io = BytesIO()
+        # io.write(row['img_raw'])
+        # io.seek(0) # rewind to start of file
+        # raw_mask = np.load(io)
         
         cursor.execute('''
             SELECT * FROM Tags
